==> v8.3.zip: ru_twords_ru_tw/bible/kt/call.md <==
# проповедовать

## Определение:

Слова “призывать” и “воззвать” буквально означают “говорить громко” кому-то, находящемуся далеко. С корнем “звать” есть также несколько слов с переносным значением.
Слово “проповедовать” может означать “объявлять”, “провозглашать”, “учить”.

* “Взывать к кому-либо” означает кричать или громко обращаться к кому-то, а также звать кого-то на помощь, особенно Бога.
* Хотя слово “призывать” означает “позвать к себе”, в Библии это слово часто имеет значение “побуждать”, “склонять” или “просить или приказывать (что-то сделать)”.
* Бог призывает людей прийти к Нему и быть Его народом. Это — их “призвание”.
* Фраза “Бог призывает” людей означает, что Бог назначил или выбрал их, чтобы они стали Его детьми, Его слугами и представителями, распространяющими Его весть спасения через Иисуса Христа.
* “Называться именем” кого-либо означает, что человеку даровано право носить имя кого-то другого. Бог говорит, что Он назвал Свой народ Своим именем.
* Фраза “Я назвал тебя по имени” означает, что Бог избрал лично этого человека.

## Варианты перевода:

* Слово “призывать” можно перевести словом, означающим “звать к Себе” с каким-то намерением или целью.
* Фразу “взывать к Тебе” можно перевести как “просить Тебя о помощи” или “усиленно молить Тебя”.
* Когда в Библии говорится, что Бог “призвал” нас быть Его слугами, то это можно перевести как “избрал нас” или “назначил нас” быть Его слугами.
* Фразу “и назовёшь его...” можно также перевести как “и дашь ему имя...”.
* Фразу “его зовут” можно перевести как “его имя...”.
* Фразу “твоё призвание” можно перевести как “твоё предназначение”, “Божье намерение о тебе” или “Божье дело, предназначенное для тебя”.
* Фразу “призывать имя Господа” можно перевести как “искать Господа и полагаться на Него” или “доверять Господу и слушаться Его”.
* Фразу “взывать о...” иногда можно перевести как “требовать”, “просить” или “повелевать”.
* Фразу “ты назван моим именем” можно перевести как “я дал тебе своё имя, чтобы ты был моим”.
* Когда Бог говорит: “Я назвал тебя по имени”, то это можно перевести как “Я знаю тебя и избрал тебя”.

(См. также: [молиться](../kt/pray.md), [кричать](../other/cry.md))

## Ссылки на библейский текст:

* [3 Цар. 18:24](rc://*/tn/help/1ki/18/24)
* [1 Фес. 4:7](rc://*/tn/help/1th/04/07)
* [2 Тим. 1:9](rc://*/tn/help/2ti/01/09)
* [Еф. 4:1](rc://*/tn/help/eph/04/01)
* [Гал. 1:15](rc://*/tn/help/gal/01/15)
* [Мф. 2:15](rc://*/tn/help/mat/02/15)
* [Флп. 3:14](rc://*/tn/help/php/03/14)

## Данные о слове:

* Номера Стронга: H559, H2199, H4744, H6817, H7121, H7123, H7769, H7773, G154, G363, G1458, G1528, G1941, G1951, G2028, G2046, G2564, G2821, G2822, G2840, G2919, G3004, G3106, G3333, G3343, G3603, G3686, G3687, G4316, G4341, G4377, G4779, G4867, G5455, G5537, G5581

==> v9.2.zip: ru_twords_ru_tw/bible/kt/call.md <==
# призывать, звать

## Определение:

Слова “призывать” и “воззвать” буквально означают “говорить громко” кому-то, находящемуся далеко. С корнем “звать” есть также несколько слов с переносным значением.
Слово “проповедовать” может означать “объявлять”, “провозглашать”, “учить”.

* “Взывать к кому-либо” означает кричать или громко обращаться к кому-то, а также звать кого-то на помощь, особенно Бога.
* Хотя слово “призывать” означает “позвать к себе”, в Библии это слово часто имеет значение “побуждать”, “склонять” или “просить или приказывать (что-то сделать)”.
* Бог призывает людей прийти к Нему и быть Его народом. Это — их “призвание”.
* Фраза “Бог призывает” людей означает, что Бог назначил или выбрал их, чтобы они стали Его детьми, Его слугами и представителями, распространяющими Его весть спасения через Иисуса Христа.
* “Называться именем” кого-либо означает, что человеку даровано право носить имя кого-то другого. Бог говорит, что Он назвал Свой народ Своим именем.
* Фраза “Я назвал тебя по имени” означает, что Бог избрал лично этого человека.

## Варианты перевода:

* Слово “призывать” можно перевести словом, означающим “звать к Себе” с каким-то намерением или целью.
* Фразу “взывать к Тебе” можно перевести как “просить Тебя о помощи” или “усиленно молить Тебя”.
* Когда в Библии говорится, что Бог “призвал” нас быть Его слугами, то это можно перевести как “избрал нас” или “назначил нас” быть Его слугами.
* Фразу “и назовёшь его...” можно также перевести как “и дашь ему имя...”.
* Фразу “его зовут” можно перевести как “его имя...”.
* Фразу “твоё призвание” можно перевести как “твоё предназначение”, “Божье намерение о тебе” или “Божье дело, предназначенное для тебя”.
* Фразу “призывать имя Господа” можно перевести как “искать Господа и полагаться на Него” или “доверять Господу и слушаться Его”.
* Фразу “взывать о...” иногда можно перевести как “требовать”, “просить” или “повелевать”.
* Фразу “ты назван моим именем” можно перевести как “я дал тебе своё имя, чтобы ты был моим”.
* Когда Бог говорит: “Я назвал тебя по имени”, то это можно перевести как “Я знаю тебя и избрал тебя”.

(См. также: [молиться](../kt/pray.md), [кричать](../other/cry.md))

## Ссылки на библейский текст:

* [3 Цар. 18:24](rc://ru/tn/help/1ki/18/24)
* [1 Фес. 4:7](rc://ru/tn/help/1th/04/07)
* [2 Тим. 1:9](rc://ru/tn/help/2ti/01/09)
* [Еф. 4:1](rc://ru/tn/help/eph/04/01)
* [Гал. 1:15](rc://ru/tn/help/gal/01/15)
* [Мф. 2:15](rc://ru/tn/help/mat/02/15)
* [Флп. 3:14](rc://ru/tn/help/php/03/14)


## Данные о слове:

* Номера Стронга: H559, H2199, H4744, H6817, H7121, H7123, H7769, H7773, G154, G363, G1458, G1528, G1941, G1951, G2028, G2046, G2564, G2821, G2822, G2840, G2919, G3004, G3106, G3333, G3343, G3603, G3686, G3687, G4316, G4341, G4377, G4779, G4867, G5455, G5537, G5581
